#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hi-file-parser
version:              0.1.2.0
visibility:           public
id:                   hi-file-parser-0.1.2.0-Ax5TbGs89FSHhZf96wNJgw
key:                  hi-file-parser-0.1.2.0-Ax5TbGs89FSHhZf96wNJgw
license:              BSD-3-Clause
maintainer:           michael@snoyman.com
author:               Hussein Ait-Lahcen
homepage:             https://github.com/commercialhaskell/hi-file-parser#readme
synopsis:             Parser for GHC'\''s hi files
description:
    Please see the README on Github at <https://github.com/commercialhaskell/hi-file-parser/blob/master/README.md>

category:             Development
abi:                  0f1c7e38002283a29bae9637efad7107
exposed:              True
exposed-modules:      HiFileParser
hidden-modules:       Paths_hi_file_parser
import-dirs:          /usr/lib/ghc-8.10.5/site-local/hi-file-parser-0.1.2.0
library-dirs:         /usr/lib/ghc-8.10.5/site-local/hi-file-parser-0.1.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/hi-file-parser-0.1.2.0
hs-libraries:         HShi-file-parser-0.1.2.0-Ax5TbGs89FSHhZf96wNJgw
depends:
    base-4.14.2.0 binary-0.8.8.0 bytestring-0.10.12.0 mtl-2.2.2
    rio-0.1.20.0-LPBfpbY87JCMYrSVKFBdH
    vector-0.12.3.0-K9OZS5OCy7cE2QKQqSO9mp

haddock-interfaces:
    /usr/share/doc/haskell-hi-file-parser/html/hi-file-parser.haddock

haddock-html:         /usr/share/doc/haskell-hi-file-parser/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

